/**
 * @file
 * Logic to initialize Instafeed.js with module settings.
 */
(function (Drupal, drupalSettings) {
  Drupal.behaviors.instafeedBlock = {
    attach: function (context, settings) {
      // Element to display the feed in.
      const instafeedId = document.getElementById('instafeed');

      if (instafeedId && !instafeedId.dataset.instafeedInitialized) {
        // Set a flag to avoid re-initialization.
        instafeedId.dataset.instafeedInitialized = true;

        // Get block form settings.
        const template = drupalSettings.instafeed_block.template;
        const limit = parseInt(drupalSettings.instafeed_block.limit);
        const filterObject = drupalSettings.instafeed_block.filters || {};
        const filters = Object.keys(filterObject);
        const accessToken = drupalSettings.instafeed_block.accessToken;

        // Initialize Instafeed.js.
        const feed = new Instafeed({
          limit: limit,
          template: template,
          accessToken: accessToken,
          // Filter the feed based on the type of media.
          filter: function(image) {
            if (filters.length > 0) {
              if (filters.includes('image') && image.type === 'image') {
                return true;
              }
              if (filters.includes('video') && image.type === 'video') {
                return true;
              }
              if (filters.includes('album') && image.type === 'album') {
                return true;
              }
              // Display all media if no filters are set.
              if (filters.length === 0) {
                return true;
              }
            }
            else {
              // Display all media if no filters are set.
              return true;
            }
          },
          // Element id to display the feed in.
          target: 'instafeed'
        });
        feed.run();
      }
    }
  };
})(Drupal, drupalSettings);
